@@ -1,11 +1,16 @@
 from __future__ import annotations
 
-from . import types, validators
+from . import http, types, validators
+from .endpoint import EndpointABC
 
 
-class Search:
+class SearchBase(EndpointABC[http.THttpClient]):
     __slots__ = ()
 
+    @property
+    def _endpoint(self) -> str:
+        return "search/cities"
+
     @staticmethod
     def _get_params_by_coordinates(
         latitude: float, longitude: float, *, limit: types.SearchLimit
@@ -26,7 +31,3 @@ class Search:
     def _get_params_by_query(query: str) -> types.Params:
         query = validators.Query.parse_obj(query).__root__
         return {"query": query}
-
-    @property
-    def _endpoint(self) -> str:
-        return "search/cities"
